User guide — scikit-hubness 0.21.0 documentation

# User guide

Welcome to `scikit-hubness`! Here we describe the core functionality of the package (hubness analysis, hubness reduction, neighbor search), and provide several usage examples.

Contents:

- Core concepts
  - The hubness phenomenon
  - The scikit-hubness package
  - Approximate nearest neighbor search methods
  - Hubness reduction methods
  - Approximate hubness reduction
- Hubness analysis
  - Hubness measures
- Hubness reduction
- Nearest neighbors
- Examples
  - Example: Hubness reduction
  - Example: Approximate nearest neighbor search
  - Example: Approximate hubness reduction
  - Example: From sklearn to skhubness